======
clisy
======

A command line utility to open browser for when you want to search something across various options

Description
===========

This is a simple utility to open browser from command line when you want to search something from various search options. Currently, it supports DuckDuckGo. But quickly, will plan to add the following options as well :

* GOOGLE ("g")
* WIKIPEDIA ("w")
* WIRECUTTER ("wc")
* AMAZON ("a")
* CREATIVE_COMMONS ("cc")
* IMDB ("imdb")

.. _pyscaffold-notes:

Note
====

This project has been set up using PyScaffold 4.0.2. For details and usage
information on PyScaffold see https://pyscaffold.org/.
